@@ -80,7 +80,7 @@ namespace Oxygen
         protected:
 
         //! event processing
-        virtual bool event( QEvent* );
+        bool event( QEvent* ) ;
 
         // menu mode from ui
         int menuMode( void ) const;
