@@ -78,10 +78,10 @@ namespace Oxygen
         AddEventFilter _addEventFilter;
 
         //! pointer to SplitterProxy
-        typedef WeakPointer<SplitterProxy> SplitterProxyPointer;
+        using SplitterProxyPointer = WeakPointer<SplitterProxy>;
 
         //! registered widgets
-        typedef QMap<QWidget*, SplitterProxyPointer > WidgetMap;
+        using WidgetMap = QMap<QWidget*, SplitterProxyPointer >;
         WidgetMap _widgets;
 
     };
@@ -99,7 +99,7 @@ namespace Oxygen
         virtual ~SplitterProxy( void );
 
         //! event filter
-        virtual bool eventFilter( QObject*, QEvent* );
+        bool eventFilter( QObject*, QEvent* ) ;
 
         //! enable state
         void setEnabled( bool );
@@ -111,7 +111,7 @@ namespace Oxygen
         protected:
 
         //! event handler
-        virtual bool event( QEvent* );
+        bool event( QEvent* ) ;
 
         protected:
 
