@@ -79,13 +79,13 @@ namespace Oxygen
         void unregisterWidget( QWidget* );
 
         //* event filter [reimplemented]
-        virtual bool eventFilter( QObject*, QEvent* );
+        bool eventFilter( QObject*, QEvent* ) ;
 
         protected:
 
         //* timer event,
         /** used to start drag if button is pressed for a long enough time */
-        void timerEvent( QTimerEvent* );
+        void timerEvent( QTimerEvent* ) ;
 
         //* mouse press event
         bool mousePressEvent( QObject*, QEvent* );
