@@ -48,7 +48,7 @@ namespace Oxygen
         public:
 
         //! shortcut to painter
-        typedef WeakPointer<TransitionWidget> Pointer;
+        using Pointer = WeakPointer<TransitionWidget>;
 
         //! constructor
         TransitionWidget( QWidget* parent, int duration );
@@ -173,10 +173,10 @@ namespace Oxygen
         protected:
 
         //! generic event filter
-        virtual bool event( QEvent* );
+        bool event( QEvent* ) ;
 
         //! paint event
-        virtual void paintEvent( QPaintEvent* );
+        void paintEvent( QPaintEvent* ) ;
 
         //! grab widget background
         /*!
